@@ -51,18 +51,6 @@ namespace Oxygen
         inline static GtkStyleClass* parentClass( void )
         { return _parentClass; }
 
-        //! parent class
-        inline static GQuark quarkRCStyle( void )
-        {
-
-            // try initialize
-            if( !_quarkRCStyle )
-            { _quarkRCStyle = g_quark_try_string( "gtk-rc-style" ); }
-
-            return _quarkRCStyle;
-
-        }
-
         //! xul info
         inline static XulInfo& xulInfo( void )
         { return _xulInfo; }
@@ -86,13 +74,6 @@ namespace Oxygen
         //! registered type
         static GType _type;
 
-        //! RC style quark
-        /*!
-        used to check whether an RCStyle was installed on a given widget or not.
-        See gtkwidet::gtk_widget_get_modifier_style()
-        */
-        static GQuark _quarkRCStyle;
-
         //! xul info, needed to properly render focus in checkboxes and radio buttons
         static XulInfo _xulInfo;
 
